﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'de', {
	auto: 'Automatisch',
	bgColorTitle: 'Hintergrundfarbe',
	colors: {
		'000': 'Schwarz',
		'800000': 'Kastanienbraun',
		'8B4513': 'Braun',
		'2F4F4F': 'Dunkles Schiefergrau',
		'008080': 'Blaugrün',
		'000080': 'Marineblau',
		'4B0082': 'Indigo',
		'696969': 'Dunkelgrau',
		B22222: 'Ziegelrot',
		A52A2A: 'Braun',
		DAA520: 'Goldgelb',
		'006400': 'Dunkelgrün',
		'40E0D0': 'Türkis',
		'0000CD': 'Mittelblau',
		'800080': 'Lila',
		'808080': 'Grau',
		F00: 'Rot',
		FF8C00: 'Dunkelorange',
		FFD700: 'Gold',
		'008000': 'Grün',
		'0FF': 'Cyan',
		'00F': 'Blau',
		EE82EE: 'Violett',
		A9A9A9: 'Dunkelgrau',
		FFA07A: 'Helles Lachsrosa',
		FFA500: 'Orange',
		FFFF00: 'Gelb',
		'00FF00': 'Lime',
		AFEEEE: 'Blasstürkis',
		ADD8E6: 'Hellblau',
		DDA0DD: 'Pflaumenblau',
		D3D3D3: 'Hellgrau',
		FFF0F5: 'Lavendel',
		FAEBD7: 'Antik Weiß',
		FFFFE0: 'Hellgelb',
		F0FFF0: 'Honigtau',
		F0FFFF: 'Azurblau',
		F0F8FF: 'Alice Blau',
		E6E6FA: 'Lavendel',
		FFF: 'Weiß',
		'1ABC9C': 'Kräftiges Cyan',
		'2ECC71': 'Smaragdgrün',
		'3498DB': 'Helles Blau',
		'9B59B6': 'Amethystblau',
		'4E5F70': 'Graublau',
		'F1C40F': 'Lebhaftes Gelb',
		'16A085': 'Dunkelcyan',
		'27AE60': 'Dunkelsmaragdgrün',
		'2980B9': 'Kräftiges Blau',
		'8E44AD': 'Dunkelviolett',
		'2C3E50': 'Entsättigtes blau',
		'F39C12': 'Orange',
		'E67E22': 'Möhrenfarben',
		'E74C3C': 'Blassrot',
		'ECF0F1': 'Glänzendes Silber',
		'95A5A6': 'Helles Graublau',
		'DDD': 'Hellgrau',
		'D35400': 'Kürbisfarben',
		'C0392B': 'Kräftiges Rot',
		'BDC3C7': 'Silber',
		'7F8C8D': 'Graucyan',
		'999': 'Dunkelgrau'
	},
	more: 'Weitere Farben...',
	panelTitle: 'Farben',
	textColorTitle: 'Textfarbe'
} );
